package djmil.cordacheckers;

import org.springframework.security.core.userdetails.User;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.stereotype.Service;

@Service
public class ApiUserDetailsService implements UserDetailsService {

    private final PasswordEncoder encoder;
    private final ShortHashManager shortHashManager;

    public ApiUserDetailsService(
		    PasswordEncoder encoder,
		    ShortHashManager shortHashManager) {
        this.encoder = encoder;
        this.shortHashManager = shortHashManager;
    }

    @Override
    public ApiUserDetails loadUserByUsername(String username) throws UsernameNotFoundException {
        String shortHash = shortHashManager.getShortHashBy(username);
        if (shortHash == null) {
            throw new UsernameNotFoundException("ShortHash for user '"
	            +username+ "' not found");
        }

        System.out.println("Load user "+username);
        
        User.UserBuilder userBuilder = User.builder();
        UserDetails user = userBuilder
            .username(username)
            .password(encoder.encode("qaz123"))
            .build();
        
        return new ApiUserDetails(user, shortHash);
    }
}
